pilas.actores.pizarra.Pizarra

Package pilas :: Package actores :: Module pizarra :: Class Pizarra |
[hide private]
[frames] | no frames]

# Class Pizarra

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                               Pizarra

Representa una superficie de dibujo inicialmente transparente.

Puedes pintar sobre esta pizarra usando métodos que simulan un lapiz, que se puede mover sobre una superficie.

Instance Methods | [hide private]
__init__(self, x=0, y=0, ancho=None, alto=None) Inicializa el actor Pizarra. | source code
dibujar_punto(self, x, y, color=colores.negro) Dibuja un punto sobre la pizarra. | source code
obtener_coordenada_fisica(self, x, y) Convierte las coordenadas de pantalla a coordenadas físicas. | source code
pintar_imagen(self, imagen, x, y) Dibuja una imagen sobre la pizarra. | source code
pintar_parte_de_imagen(self, imagen, origen_x, origen_y, ancho, alto, x, y) Dibuja una porción de una imagen sobre la pizarra. | source code
pintar_grilla(self, grilla, x, y) Dibuja un cuadro de animación sobre la pizarra. | source code
pintar(self, color) Pinta toda la pizarra de un solo color. | source code
linea(self, x, y, x2, y2, color=colores.negro, grosor=1) Dibuja una linea recta sobre la pizarra. | source code
rectangulo(self, x, y, ancho, alto, color=colores.negro, relleno=False, grosor=1) Dibuja un rectángulo sobre la pizarra. | source code
texto(self, cadena, x=0, y=0, magnitud=10, fuente=None, color=colores.negro) Dibuja una cadena de texto sobre la pizarra. | source code
poligono(self, puntos, color=colores.negro, grosor=1) Dibuja un polígono sobre la pizarra. | source code
limpiar(self) Borra toda la pizarra y los dibujos que hay en ella. | source code
Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, x=0, y=0, ancho=None, alto=None) (Constructor) | source code
Inicializa el actor Pizarra. :param x: Posición horizontal inicial. :param y: Posición horizontal inicial. :param ancho: El tamaño horizontal en pixels, si no se especifica será el tamaño de la ventana. :param alto: El tamaño vertical en pixels, si no se especifica será el tamaño de la ventana. Overrides: estudiante.Estudiante.__init__

### dibujar_punto(self, x, y, color=colores.negro) | source code
Dibuja un punto sobre la pizarra. El punto será 3 pixels de radio, y si no se especifica tendrá color negro. Este es un ejemplo de invocación:
    >>> pizarra.dibujar_punto(20, 30, pilas.colores.rojo)
:param x: Posición horizontal para el punto. :param y: Posición vertical para el punto. :param color: El color para el punto.

### obtener_coordenada_fisica(self, x, y) | source code
Convierte las coordenadas de pantalla a coordenadas físicas. Una coordenanda de pantalla, comienza en el punto (0, 0) y corresponde al centro de la pizarra. Mientras que una coordenada física tiene un sistema parecido al de los juegos viejos, donde (0, 0) es la esquina superir izquierda de la pantalla. :param x: Coordenada x a convertir. :param y: Coordenada y a convertir.

### pintar_imagen(self, imagen, x, y) | source code
Dibuja una imagen sobre la pizarra. :param imagen: Referencia a la imagen que se quiere pintar. :param x: Coordenada destino horizontal. :param y: Coordenada destino vertical.

### pintar_parte_de_imagen(self, imagen, origen_x, origen_y, ancho, alto, x, y) | source code
Dibuja una porción de una imagen sobre la pizarra. Este método, a diferencia de "pintar_imagen", capturará un rectángulo de la imagen fuente. :param imagen: Imagen fuente que se quiere dibujar sobre la pizarra. :param origen_x: Marca la esquina superior izquierda desde donde se recortar. :param origen_y: Marca la esquina superior izquierda desde donde se recortar. :param ancho: Ancho del rectángulo de corte. :param alto: Alto del rectángulo de corte.

### pintar_grilla(self, grilla, x, y) | source code
Dibuja un cuadro de animación sobre la pizarra. :param grilla: La grilla a dibujar. :param x: Coordenada horizontal sobre la pizarra. :param y: Coordenada vertical sobre la pizarra.

### pintar(self, color) | source code
Pinta toda la pizarra de un solo color. Por ejemplo:
    >>> pizarra.pintar(pilas.colores.rojo)
:param color: El color que pintará toda la pizarra.

### linea(self, x, y, x2, y2, color=colores.negro, grosor=1) | source code
Dibuja una linea recta sobre la pizarra. :param x: Coordenada horizontal desde donde comenzará la linea. :param y: Coordenada vertical desde donde comenzará la linea. :param x2: Coordenada horizontal desde donde terminará la linea. :param y2: Coordenada vertical desde donde terminará la linea. :param color: El color de la linea. :param grosor: Cuan gruesa será la linea en pixels.

### rectangulo(self, x, y, ancho, alto, color=colores.negro, relleno=False, grosor=1) | source code
Dibuja un rectángulo sobre la pizarra. Si el rectángulo se dibuja con relleno, el color será el que pintará todo el rectángulo, en caso contrario, el color será utilizado para dibujar el contorno del rectángulo. :param x: Posición horizontal de la esquina superior izquierda. :param y: Posición horizontal de la esquina superior izquierda. :param ancho: Ancho del rectángulo. :param alto: Altura del rectángulo. :param relleno: Indica con True o False si el rectángulo se tiene que pintar completamente. :param grosor: Grosor del contorno del rectángulogulo.

### texto(self, cadena, x=0, y=0, magnitud=10, fuente=None, color=colores.negro) | source code
Dibuja una cadena de texto sobre la pizarra. :param cadena: El string que se quiere dibujar. :param x: Coordenada horizontal. :param y: Coordenada vertical. :param magnitud: Tamaño que tendrá la tipografía. :param fuente: Nombre de la tipografía a utilizar. :param color: Color del texto a dibujar.

### poligono(self, puntos, color=colores.negro, grosor=1) | source code
Dibuja un polígono sobre la pizarra. Ejemplo:
    >>> pizarra = pilas.actores.Pizarra()
    >>> pizarra.poligono([(10, 20), (100, 140)], color=pilas.colores.verde, grosor=4)
:param puntos: Una lista de puntos en forma de tupla (x, y) que conforman el polígono. :param color: El color de la linea a trazar. :param grosor: El grosor de la linea a trazar en pixels.